#! /usr/bin/ruby
#
# pstopng.rb
#
#   convert ps file to png or eps
#
#   by Eriko Nishimoto 

require 'getoptlong.rb'

parser = GetoptLong.new
parser.set_options(
  ['--resolution','--r', GetoptLong::REQUIRED_ARGUMENT],
  ['--output','--o', GetoptLong::REQUIRED_ARGUMENT],
  ['--outdir','--odir', GetoptLong::REQUIRED_ARGUMENT],
  ['--norotate', GetoptLong::NO_ARGUMENT],
  ['--margin', '--m', GetoptLong::REQUIRED_ARGUMENT],
  ['--nopng', GetoptLong::NO_ARGUMENT],
  ['--help', '-h', GetoptLong::NO_ARGUMENT]
)

#-- initial values
#resl = 150          # defalut resolution
resl = 100          # defalut resolution
outfname = false
outdir = false
outformat = "png"
norotate = false
rotate = 90
alpha = false
margin = 0.05
no_png = false
help = false

#-- get input values
parser.each_option do |name,arg|
  name.sub!(/^--/,'')
  case name
  when 'resolution' , 'r'
    resl = arg.to_i
  when 'output' , 'o'
    outfname = arg.to_s
  when 'outdir' , 'odir'
    outdir = arg.to_s
  when 'outformat'
    outformat = arg.to_s
  when 'norotate'
    norotate = true
  when 'rotate'
    rotate = arg.to_i
  when 'alpha'
    alpha = true
  when 'margin' , 'm'
    margin = arg.to_f
  when 'nopng'
    no_png = true
  when 'help' , 'h'
    help = true
  end
end

#-- help message
if (help)
  usage = "Usage: #{$0.split('/')[-1]}
    --r, --resolution [value]   specify output resolution in DPI ( default #{resl} )
    --o, --output [string]      specify name of output png file 
    --odir, --outdir [string]   specify output directory
    --outformat [string]        specify output format ( default #{outformat} )
    --norotate                  without rotating ( default #{norotate} )
    --m, --margin [value]       ratio of border to real figure size ( default #{margin} )
    --alpha                     alpha ( default #{norotate} )
    --nopng                     do not create png. only trim
    -h, --help                  show this message"
  puts usage
  exit
end

#-- make ps file to png
home = Dir.getwd

ARGV.each{|input|

  ok = File.exist?(input)
  if (not ok)
    puts "Not exist #{input} !!\n\n"
    next
  end

  dirname = File.dirname(input)
  pdffname = File.basename(input)
  outfname = File.basename(input,'.pdf')
  #puts "-----------------------\n"
  #puts "#{outfname}"
  puts "\n----------------------- #{outfname}"

  Dir.chdir(dirname)

  #---------------------- pdf to png (pdftoppm)
  tmpfname_base="hoge8819101"
  puts "\nPDF -> PNG (pdftoppm)"
  cmd="pdftoppm -#{outformat}"
  cmd<<" -r #{resl}"
  cmd<<" #{pdffname} #{tmpfname_base}"

  #p cmd
  system( cmd )

  #---------------------- pdf to png
  puts "\nPNG forming (convert)"
  cmd="convert -trim"
  cmd<<" -alpha off" if alpha
  cmd<<" -rotate #{rotate}" if not norotate
  cmd<<" #{tmpfname_base}-?.#{outformat} #{outfname}.#{outformat}"

  #p cmd
  system( cmd )

  #---------------------- clean up
  puts "\nremove tmpfile ..."
  system("rm -f #{tmpfname_base}-?.#{outformat}")

  Dir.chdir(home)

  if outdir
    puts "\nmove to #{outdir}\n"
    system("mv #{dirname}/#{outfname}.#{outformat} #{outdir}")
  end
}

